@@ -35,6 +35,7 @@ CONNECTIVITY_UNKNOWN = None
 DEFAULT_TILE_STORAGE_TYPE = "files"
 TILE_STORAGE_FILES = "files"
 TILE_STORAGE_SQLITE = "sqlite"
+TILE_STORAGE_TYPES = [TILE_STORAGE_FILES, TILE_STORAGE_SQLITE]
 
 # GTK GUI
 PANGO_ON = '<span color="green">ON</span>'
@@ -105,8 +106,14 @@ DEVICE_TYPE_DESKTOP = 1
 DEVICE_TYPE_SMARTPHONE = 2
 DEVICE_TYPE_TABLET = 3
 
+# providers
+ROUTING_PROVIDER_GOOGLE = "GoogleDirections"
+ROUTING_PROVIDER_MONAV = "Monav"
+ROUTING_PROVIDER_ROUTINO = "Routino"
+
 # routing
 ROUTE_DEFAULT_LANGUAGE = "en"
+DEFAULT_ROUTING_PROVIDER = ROUTING_PROVIDER_GOOGLE
 
 # Monav routing return codes
 ROUTING_SUCCESS = 0
