@@ -26,6 +26,8 @@ import time
 import logging
 log = logging.getLogger("core.startup")
 
+from core import modrana_log
+
 try:
     import argparse
 except ImportError:
@@ -40,15 +42,28 @@ SEARCH_PROVIDER_TIMEOUT_ERROR = 4
 SEARCH_PROVIDER_ERROR = 5
 LOCAL_SEARCH_CURRENT_POSITION_UNKNOWN_ERROR = 6
 CURRENT_POSITION_UNKNOWN_ERROR = 7
+COORDINATE_PARSING_ERROR = 8
 
 USE_LAST_KNOWN_POSITION_KEYWORD = "LAST_KNOWN_POSITION"
 
+POI_SUBCOMMAND = "poi"
+
+SUBCOMMAND_LIST = [POI_SUBCOMMAND]
+
+SUBCOMMANDS = set(SUBCOMMAND_LIST)
 
 class Startup(object):
     def __init__(self, modrana):
         self.modrana = modrana
         self.originalStdout = None
-        parser = argparse.ArgumentParser(description="A flexible GPS navigation system.")
+        self.originalStderr = None
+        self._subcommand_present = len(sys.argv) >= 2 and sys.argv[1] in SUBCOMMANDS
+        self._poi_subcommand_present = False
+        current_subcommands = ",".join(SUBCOMMAND_LIST)
+        parser = argparse.ArgumentParser(description="A flexible GPS navigation system.",
+                                         epilog="You can also use the following subcommands: [%s] \
+                                                 To see what a subcommand does use <subcommand> --help, \
+                                                 EXAMPLE: poi --help" % current_subcommands)
         # device
         parser.add_argument(
             '-d', metavar="device ID", type=str,
@@ -100,6 +115,8 @@ class Startup(object):
             default=None,
             action="store"
         )
+
+
         # return static map url & shutdown
         parser.add_argument(
             '--return-static-map-url',
@@ -163,6 +180,40 @@ class Startup(object):
             action="store_true"
         )
 
+        # subcommands
+        #
+        # As argparse does not support support optional subcommands
+        # (non-optional subcommands would preclude running modrana without arguments
+        #  or with the current optional arguments), so only register subcommands if
+        # they are spotted in sys.argv. Like this the subcommands don't show up in the
+        # automatically generated help, which we workaround by mentioning the available
+        # subcommands in the epilog.
+        # Handling subcommands like this also has the benefit of skipping all the subcommand
+        # setup code when the subcommand is not actually needed a even if a subcommand is
+        # spotted only a single subcommand is setup, not all of them.
+
+        if self._subcommand_present:
+            subcommand = sys.argv[1]
+            if subcommand == POI_SUBCOMMAND:
+                # poi subcommand
+                self._poi_subcommand_present = True
+                subcommands = parser.add_subparsers()
+                poi = subcommands.add_parser("poi", help="Points of Interest handling")
+                poi.required = False
+                poi_subcommands = poi.add_subparsers(dest="poi_subcommand")
+                # add
+                poi_add = poi_subcommands.add_parser("add", help='add a POI to the database')
+                poi_add.add_argument(type=str, dest="poi_add_coords", default=None, nargs="?",
+                                     help='geographic coordinates with the geo: prefix, EXAMPLE: "geo:50.083333,14.416667"')
+                poi_add.add_argument("--name", type=str, dest="poi_name",
+                                     help='POI name, EXAMPLE: "Baker Street 221b, London"')
+                poi_add.add_argument("--description", type=str,  dest="poi_description",
+                                     help='POI name, EXAMPLE: "The house of Sherlock Holmes."')
+                poi_add.add_argument("--category", type=str, dest="poi_category", default="Other",
+                                         help='POI category name or index (default: 11/Other), EXAMPLE: "Landmark" or "10"')
+                # list-categories
+                poi_subcommands.add_parser("list-categories", help='list POI database categories')
+
         self.args, _unknownArgs = parser.parse_known_args()
 
 
@@ -186,6 +237,8 @@ class Startup(object):
                 self._disableStdout()
         elif self.args.return_current_coordinates:
             self._disableStdout()
+        elif self._poi_subcommand_present:
+            self._disableStdout()
 
     def handleNonGUITasks(self):
         """Handle CLI arguments that can be handled before the general modRana startup,
@@ -204,8 +257,11 @@ class Startup(object):
                 self._earlyWikipediaSearch()
         elif self.args.return_current_coordinates:
             self._earlyReturnCoordinates()
-
-
+        elif self._poi_subcommand_present:
+            if self.args.poi_subcommand == "add":
+                self._addPOI()
+            elif self.args.poi_subcommand == "list-categories":
+                self._listCategories()
 
     def handlePostFirstTimeTasks(self):
         """
@@ -367,6 +423,69 @@ class Startup(object):
             # done - no position found
             self._exit(CURRENT_POSITION_UNKNOWN_ERROR)
 
+    # POI
+
+    def _find_category(self, store_poi, cat_spec):
+        """Try to match the cat_spec to a POI category.
+           The category specification is expected to be either an integer index
+           or a category name.
+
+           :param str cat_cat_spec: category specification
+           :returns: category index, category name or None, None if cat_spec can't be matched to a category
+           :rtype: tuple
+        """
+        try:
+            # first try converting the spec to the integer index
+            result = store_poi.db.get_category_from_index(int(cat_spec))
+        except ValueError:
+            # next try to fetch category for the name
+            result = store_poi.db.get_category_from_name(cat_spec)
+        if result:  # category found
+            cat_id, cat_name, _desc, _enabled = result
+            return cat_id, cat_name
+        else:  # category not found
+            return None, None
+
+    def _addPOI(self):
+        """Add a poi to the database"""
+        self._disableStdout()
+        from core import geo
+        coords = geo.parse_geo_coords(self.args.poi_add_coords)
+        if coords is None:
+            self._enableStdout()
+            print("coordinate format parsing failed, should be: geo:latitude,longitude")
+            self._exit(COORDINATE_PARSING_ERROR)
+        else:
+            from core.point import POI
+            lat, lon = coords
+            store_poi = self.modrana._loadModule("mod_storePOI", "storePOI")
+            cat_id, cat_name = self._find_category(store_poi, self.args.poi_category)
+            if cat_id is None:
+                self._enableStdout()
+                print("invalid category specification (%s), falling back to default (%s)" %
+                      (self.args.poi_category, "Other"))
+                self._disableStdout()
+                cat_id = 11
+                cat_name = "Other"
+
+            poi = POI(lat=lat, lon=lon, name=self.args.poi_name,
+                      description=self.args.poi_description,
+                      db_cat_id=cat_id)
+            store_poi.db.store_poi(poi)
+            self._enableStdout()
+            print("point added to the modRana POI database (category: %d/%s)" % (cat_id, cat_name))
+            self._exit(0)
+
+    def _listCategories(self):
+        """List POI database categories"""
+        self._disableStdout()
+        store_poi = self.modrana._loadModule("mod_storePOI", "storePOI")
+        categories = store_poi.db.list_categories()
+        self._enableStdout()
+        for name, description, index in categories:
+            print("%d, %s, %s" % (index, name, description))
+        self._exit(0)
+
     def _returnStaticMapUrl(self, results, online):
         """return static map url for early search methods & exit"""
         if results:
@@ -543,6 +662,13 @@ class Startup(object):
             sys.stdout = self.originalStdout
             self.originalStdout = None
 
+        if self.originalStderr:
+            sys.stderr = self.originalStderr
+            self.originalStderr = None
+
+        # re-enable logging to stdout
+        modrana_log.log_manager.enableStdoutLog()
+
     def _disableStdout(self):
         """disable stdout output
         -> this is mainly used for CLI processing so that modRanas status messages don't get into the output
@@ -556,6 +682,13 @@ class Startup(object):
             self.originalStdout = sys.stdout
             sys.stdout = self
 
+        if self.originalStderr is None:
+            self.originalStderr = sys.stderr
+            sys.stdout = self
+
+        # also disable output to stdout from our logging infrastructure
+        modrana_log.log_manager.disableStdoutLog()
+
     def write(self, s):
         """a write function that does nothing for stdout redirection"""
         pass
