@@ -59,6 +59,9 @@ def setCorrectCWD():
     # - at the same just a simple "import foo" import is enough and
     #   "from core.bundle import foo" is not needed
     sys.path.append(os.path.join(currentAbsolutePath, 'core', 'bundle'))
+    # do the same thing for the backports folder, which serves a similar role
+    # as the bundle folder (TODO: merge content of backports to bundle ?)
+    sys.path.append(os.path.join(currentAbsolutePath, 'core', 'backports'))
     #sys.path.append(os.path.join('core', 'bundle'))
     #sys.path.append(os.path.join("qrc:/", 'core', 'bundle'))
     # add the modules folder to path, so that third-party modules (such as Upoints),
@@ -237,7 +240,7 @@ class ModRana(object):
         # get GUI ID from the CLI argument
         if self.args.u:
             try:
-                self.GUIString = self.args.u.split(":")[0]
+                self.GUIString = self.args.u.split(":")[0].upper()
             except Exception:
                 log.exception('splitting the GUI string failed')
         else: # no ID specified
@@ -302,7 +305,7 @@ class ModRana(object):
             gui = self._loadModule("gui_gtk", "gui")
         elif GUIModuleId == "QML":
             gui = self._loadModule("gui_qml", "gui")
-        elif GUIModuleId == "qt5":
+        elif GUIModuleId == "QT5":
             gui = self._loadModule("gui_qt5", "gui")
 
         # make device module available to the GUI module
@@ -508,13 +511,13 @@ class ModRana(object):
         start shutdown cleanup and stop GUI main loop
         when finished
         """
+        start_timestamp = time.clock()
         log.info("Shutting-down modules")
         for m in self.m.values():
             m.shutdown()
         self._saveOptions()
-        time.sleep(2) # leave some times for threads to shut down
         modrana_log.log_manager.disable_log_file()
-        log.info("Shutdown complete")
+        log.info("Shutdown complete (%s)" % utils.get_elapsed_time_string(start_timestamp))
 
 
     ## OPTIONS SETTING AND WATCHING ##
@@ -742,6 +745,15 @@ class ModRana(object):
         #     sTimeout = msTimeout / 1000.0
         #     notify.handleNotification(message, sTimeout, icon)
 
+    def sendMessage(self, message):
+        m = self.m.get("messages", None)
+        if m is not None:
+            log.info("Sending message: " + message)
+            m.routeMessage(message)
+        else:
+            log.error("No message handler, can't send message.")
+
+
     def getModes(self):
         """return supported modes"""
         modes = {
