@@ -86,8 +86,8 @@ class DeviceN900(DeviceModule):
             # liblocation
             self.lControl = None
             self.lDevice = None
-            """location starting is handled by mod_location
-            in its firstTime call"""
+            # location startup is handled by mod_location
+            # in its firstTime call
 
             # libconic
             self._conicConnect()
@@ -283,7 +283,7 @@ class DeviceN900(DeviceModule):
         topWindow = self.modrana.gui.getWindow()
         banner = hildon.hildon_banner_show_information_with_markup(topWindow, icon, message)
         if msTimeout:
-            banner.set_timeout(msTimeout)
+            banner.set_timeout(int(msTimeout))
 
     def hasButtons(self):
         """the N900 has the volume keys (2 buttons), the camera trigger (2 states)
