@@ -47,15 +47,15 @@ def simplePythagoreanDistance(x1, y1, x2, y2):
     return math.sqrt(dx ** 2 + dy ** 2)
 
 
-def getModule(m, d, i):
-    return GTKGUI(m, d, i)
+def getModule(*args, **kwargs):
+    return GTKGUI(*args, **kwargs)
 
 
 class GTKGUI(GUIModule):
     """A GTK GUI module"""
 
-    def __init__(self, m, d, i):
-        GUIModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        GUIModule.__init__(self, *args, **kwargs)
 
         # some constants
         self.msLongPress = 400
@@ -120,6 +120,7 @@ class GTKGUI(GUIModule):
 
         event_box.connect("button_press_event", self.mw.pressed)
         event_box.connect("button_release_event", self.mw.released)
+        event_box.connect("scroll_event", self.mw.scrolled)
         event_box.connect("motion_notify_event", self.mw.moved)
         win.add(event_box)
 
@@ -470,6 +471,9 @@ class MainWidget(gtk.Widget):
         if not self.pressLengthTimer:
             self.pressLengthTimer = gobject.timeout_add(50, self.checkStillPressed, event.time, time.time(), event.x,
                                                         event.y)
+        # check for double-click
+        if event.type == gdk._2BUTTON_PRESS:
+            self.doubleClick(event.x, event.y)
 
     def moved(self, w, event):
         """Drag-handler"""
@@ -506,6 +510,12 @@ class MainWidget(gtk.Widget):
         if distSq < CLICK_DRAG_THRESHOLD:
             self.click(event.x, event.y, msDuration)
 
+    def scrolled(self, w, event):
+        """mouse wheel scrolling"""
+        m = self.modrana.getModule("clickHandler", None)
+        if m:
+            m.handleScrolling(event)
+
     def checkStillPressed(self, pressStartEpoch, pressStartTime, startX, startY):
         """check if a press is still in progress and report:
         pressStart epoch - to differentiate presses
@@ -534,6 +544,12 @@ class MainWidget(gtk.Widget):
         if m:
             m.handleClick(x, y, msDuration)
 
+    def doubleClick(self, x, y):
+        """this fires after a double-click is detected"""
+        m = self.modrana.getModule("clickHandler", None)
+        if m:
+            m.handleDoubleClick(x, y)
+
     def handleDrag(self, x, y, dx, dy, startX, startY, msDuration):
         """handle dragging on the screen"""
         # check if centering is on
