@@ -20,12 +20,12 @@
 from modules.base_module import RanaModule
 
 
-def getModule(m, d, i):
-    return Input(m, d, i)
+def getModule(*args, **kwargs):
+    return Input(*args, **kwargs)
 
 
 class Input(RanaModule):
     """Handle input from keyboard, buttons, etc."""
 
-    def __init__(self, m, d, i):
-        RanaModule.__init__(self, m, d, i)
\ No newline at end of file
+    def __init__(self, *args, **kwargs):
+        RanaModule.__init__(self, *args, **kwargs)
\ No newline at end of file
