@@ -558,8 +558,8 @@ class Options(RanaModule):
         # ** tile storage
         group = addGroup("Tile storage", "tile_storage", catMap, "generic")
         addOpt("Tile storage", "tileStorageType",
-               [('files', "files (default, more space used)"),
-                ('sqlite', "sqlite (new, less space used)")],
+               [(constants.TILE_STORAGE_FILES, "files (default, more space used)"),
+                (constants.TILE_STORAGE_SQLITE, "sqlite (new, less space used)")],
                group,
                self.modrana.dmod.defaultTileStorageType)
         addBoolOpt("Store downloaded tiles", "storeDownloadedTiles", group, True)
@@ -1081,8 +1081,8 @@ class Options(RanaModule):
         addBoolOpt("Log file compression", "compressLogFile", group, False)
         # ** tiles
         group = addGroup("Tiles", "tiles", catDebug, "generic")
-        addBoolOpt("Print tile cache status to terminal", "reportTileCacheStatus", group, False)
-        addBoolOpt("Tile loading status to terminal", "tileLoadingDebug", group, False)
+        addBoolOpt("Ttile cache status debugging messages", "reportTileCacheStatus", group, False)
+        addBoolOpt("Tile storage debugging messages", "tileLoadingDebug", group, False)
         addBoolOpt("Redraw screen once a new tile is loaded", "tileLoadedRedraw", group, True)
         addOpt("In memory tile cache size", "memoryTileCacheSize",
                [(20, "20", notifyRestartNeeded),
