@@ -24,8 +24,9 @@ import time
 import os
 from collections import deque
 from core import geo
-from core import way
+from core.way import Way, AppendOnlyWay
 from core import gs
+from core.signal import Signal
 
 if gs.GUIString == "GTK":
     import gtk
@@ -42,15 +43,15 @@ DONT_ADD_TO_TRACE_THRESHOLD = 1
 # NOTE: all points are still stored, just not drawn
 
 
-def getModule(m, d, i):
-    return Tracklog(m, d, i)
+def getModule(*args, **kwargs):
+    return Tracklog(*args, **kwargs)
 
 
 class Tracklog(RanaModule):
     """Record tracklogs"""
 
-    def __init__(self, m, d, i):
-        RanaModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        RanaModule.__init__(self, *args, **kwargs)
         self.loggingEnabled = False
         self.loggingPaused = False
         self.loggingStartTimestamp = 0
@@ -68,6 +69,8 @@ class Tracklog(RanaModule):
         # timer ids
         self.updateLogTimerId = None
         self.saveLogTimerId = None
+        # signals
+        self.tracklogUpdated = Signal()
         # statistics
         self.maxSpeed = 0
         self.avg1 = 0
@@ -194,12 +197,12 @@ class Tracklog(RanaModule):
             path1 = os.path.join(logFolder, "%s.temporary_csv_1" % name)
             path2 = os.path.join(logFolder, "%s.temporary_csv_2" % name)
 
-            log1 = way.AppendOnlyWay()
-            log1.startWritingCSV(path1)
+            log1 = AppendOnlyWay()
+            log1.start_writing_csv(path1)
             self.log1 = log1
 
-            log2 = way.AppendOnlyWay()
-            log2.startWritingCSV(path2)
+            log2 = AppendOnlyWay()
+            log2.start_writing_csv(path2)
             self.log2 = log2
 
             # start update and save timers
@@ -271,8 +274,8 @@ class Tracklog(RanaModule):
             timestamp = geo.timestampUTC()
             lat, lon = pos
             elevation = self.get('elevation', None)
-            self.log1.addPointLLET(lat, lon, elevation, timestamp)
-            self.log2.addPointLLET(lat, lon, elevation, timestamp)
+            self.log1.add_point_llet(lat, lon, elevation, timestamp)
+            self.log2.add_point_llet(lat, lon, elevation, timestamp)
 
             # update statistics for the current log
             if self.loggingEnabled and not self.loggingPaused:
@@ -309,6 +312,40 @@ class Tracklog(RanaModule):
                         self._addLL2Trace(lat, lon)
                 else: # this is the first known log point, just add it
                     self._addLL2Trace(lat, lon)
+        # done, trigger the tracklog updated signal
+        self.tracklogUpdated()
+
+    def getStatusDict(self):
+        """Return status of the current track logging as a dictionary
+        This is used by the Qt 5 GUI to show the various logging related
+        statistics.
+
+        :returns: dictionary describing current track logging state
+        """
+
+        self.log.debug("generating stuff")
+
+        pointCount = 0
+        units = self.m.get('units', None)
+        if self.log1:
+            pointCount = self.log1.point_count
+
+        speed = self.get('speed', 0)
+        if speed is not None:
+            speed = units.km2CurrentUnitPerHourString(speed)
+        else:
+            speed = "unknown"
+
+        return {
+            "speed" : {
+                "current" : speed,
+                "max" : units.km2CurrentUnitPerHourString(self.maxSpeed),
+                "avg" : units.km2CurrentUnitPerHourString(self.avgSpeed)
+            },
+            "distance" : units.km2CurrentUnitString(self.distance, 2),
+            "elapsedTime" : time.strftime('%H:%M:%S', time.gmtime(int(time.time()) - self.loggingStartTimestamp)),
+            "pointCount" : pointCount
+        }
 
     def _addLL2Trace(self, lat, lon):
         proj = self.m.get('projection')
@@ -413,8 +450,8 @@ class Tracklog(RanaModule):
 
         # delete the temporary log files
         if deleteTempLogs:
-            self.log1.deleteFile()
-            self.log2.deleteFile()
+            self.log1.delete_file()
+            self.log2.delete_file()
         self.log1 = None
         self.log2 = None
 
@@ -687,7 +724,7 @@ class Tracklog(RanaModule):
                     # export any found files
                     self.log.info('exporting %s to GPX', logPath)
                     try:
-                        w1 = way.fromCSV(logPath, delimiter=",")
+                        w1 = Way.from_csv(logPath, delimiter=",")
                         exportPath = "%s.gpx" % os.path.splitext(logPath)[0]
                         # does the GPX file already exist ?
                         # TODO: check if the GPX file is corrupted and swap with newly exported one ?
@@ -730,7 +767,7 @@ class Tracklog(RanaModule):
                     # export any found files
                     self.log.info('exporting %s to GPX' % logPath)
                     try:
-                        w2 = way.fromCSV(logPath, delimiter=",")
+                        w2 = Way.from_csv(logPath, delimiter=",")
                         exportPath = "%s.gpx" % os.path.splitext(logPath)[0]
                         # does the GPX file already exist ?
                         # TODO: check if the GPX file is corrupted and swap with newly exported one ?
@@ -760,4 +797,4 @@ class Tracklog(RanaModule):
     def shutdown(self):
         # try to stop and save the log
         if self.loggingEnabled:
-            self.stopLogging()
\ No newline at end of file
+            self.stopLogging()
