@@ -116,7 +116,7 @@ class TurnByTurn(RanaModule):
         elif message == "showMessageInsideNotification":
             currentStep = self.getCurrentStep()
             if currentStep:
-                message = "<i>turn description:</i>\n%s" % currentStep.getMessage()
+                message = "<i>turn description:</i>\n%s" % currentStep.description
                 if self.dmod.hasNotificationSupport():
                     self.dmod.notify(message, 7000)
                     #TODO: add support for modRana notifications once they support line wrapping
@@ -222,14 +222,14 @@ class TurnByTurn(RanaModule):
                     layout = pg.create_layout()
 
                     # get the current turn message
-                    message = currentStep.getMessage()
+                    message = currentStep.description
 
                     # display current distance to the next point & other unit conversions
                     units = self.m.get('units', None)
                     if units and self.currentDistance:
                         distString = units.m2CurrentUnitString(self.currentDistance, 1, True)
-                        if currentStep.getDistanceFromStart():
-                            currentDistString = units.m2CurrentUnitString(currentStep.getDistanceFromStart(), 1, True)
+                        if currentStep.distanceFromStart:
+                            currentDistString = units.m2CurrentUnitString(currentStep.distanceFromStart, 1, True)
                         else:
                             currentDistString = "?"
                         routeLengthString = units.m2CurrentUnitString(self.mRouteLength, 1, True)
@@ -367,7 +367,7 @@ class TurnByTurn(RanaModule):
             return voice.say(text, espeakLanguageCode)
 
     def getMaxStepIndex(self):
-        return self.route.getMessagePointCount() - 1
+        return self.route.message_point_count - 1
 
     def getStartingStep(self, which='first'):
         if self.route:
@@ -382,11 +382,11 @@ class TurnByTurn(RanaModule):
         pos = self.get('pos', None) # and current position
         if pos and proj:
             (lat1, lon1) = pos
-            tempSteps = self.route.getMessagePoints()
+            tempSteps = self.route.message_points
             for step in tempSteps:
                 (lat2, lon2) = step.getLL()
-                step.setCurrentDistance = geo.distance(lat1, lon1, lat2, lon2) * 1000 # km to m
-            closestStep = sorted(tempSteps, key=lambda x: x.getCurrentDistance())[0]
+                step.currentDistance = geo.distance(lat1, lon1, lat2, lon2) * 1000 # km to m
+            closestStep = sorted(tempSteps, key=lambda x: x.currentDistance)[0]
 
             return closestStep
 
@@ -397,27 +397,27 @@ class TurnByTurn(RanaModule):
             self.log.error("wrong turn index: %d, max index is: %d", index, maxIndex)
             return None
         else:
-            return self.route.getMessagePointByID(index)
+            return self.route.get_message_point_by_index(index)
 
     def setStepAsCurrent(self, step):
         """set a given step as current step"""
-        mpId = self.route.getMessagePointID(step)
+        mpId = self.route.get_message_point_index(step)
         self._setCurrentStepIndex(mpId)
 
     def getCurrentStep(self):
         """return current step"""
-        return self.route.getMessagePointByID(self.currentStepIndex)
+        return self.route.get_message_point_by_index(self.currentStepIndex)
 
     def getStepID(self, step):
-        return self.route.getMessagePointID(step)
+        return self.route.get_message_point_index(step)
 
     def getCurrentStepVisitStatus(self):
         """report visit status for  current step"""
-        return self.getCurrentStep().getVisited()
+        return self.getCurrentStep().visited
 
     def markCurrentStepAsVisited(self):
         """mark current step as visited"""
-        self.getCurrentStep().setVisited(True)
+        self.getCurrentStep().visited = True
 
     def switchToPreviousStep(self):
         """switch to previous step and clean up"""
@@ -475,14 +475,14 @@ class TurnByTurn(RanaModule):
             if route: # is the route nonempty ?
                 self.route = route
                 # get route in radians for automatic rerouting
-                self.radiansRoute = route.getPointsLLERadians(dropElevation=True)
+                self.radiansRoute = route.get_points_lle_radians(drop_elevation=True)
                 # start rerouting watch
                 self._startTBTWorker()
 
                 # show the warning message
                 self.sendMessage('ml:notification:m:use at own risk, watch for cliffs, etc.;3')
                 # for some reason the combined distance does not account for the last step
-                self.mRouteLength = route.getLength()
+                self.mRouteLength = route.length
 
                 # some statistics
                 metersPerSecSpeed = self.get('metersPerSecSpeed', None)
@@ -532,7 +532,7 @@ class TurnByTurn(RanaModule):
                             # with current distance to this step,
                             # to assure there is some voice output immediately after
                             # getting a new route or rerouting"""
-                            plaintextMessage = nextStep.getSSMLMessage()
+                            plaintextMessage = nextStep.ssmlMessage
                             self.sayTurn(plaintextMessage, pos2nextStep)
                         else:
                             # we have probably not yet reached the closest step,
@@ -682,7 +682,7 @@ class TurnByTurn(RanaModule):
                 if self.espeakSecondTrigger == False:
                     self.log.debug("triggering espeak nr. 2")
                     # say the message without distance
-                    plaintextMessage = currentStep.getSSMLMessage()
+                    plaintextMessage = currentStep.ssmlMessage
                     # consider turn said even if it was skipped (ignore errors)
                     self.sayTurn(plaintextMessage, 0)
                     self.markCurrentStepAsVisited() # mark this point as visited
@@ -694,14 +694,14 @@ class TurnByTurn(RanaModule):
                     # this means we reached an optimal distance for saying the message"""
                     if self.espeakFirstTrigger == False:
                         self.log.debug("triggering espeak nr. 1")
-                        plaintextMessage = currentStep.getSSMLMessage()
+                        plaintextMessage = currentStep.ssmlMessage
                         if self.sayTurn(plaintextMessage, currentDistance):
                             self.espeakFirstTrigger = True # first message done
                 if self.espeakFirstAndHalfTrigger == False and warnTime > 30:
                     if currentDistance <= (20.0 * metersPerSecSpeed):
                         # in case that the warning time gets too big, add an intermediate warning at 20 seconds
                         # NOTE: this means it is said after the first trigger
-                        plaintextMessage = currentStep.getSSMLMessage()
+                        plaintextMessage = currentStep.ssmlMessage
                         if self.sayTurn(plaintextMessage, currentDistance):
                             self.espeakFirstAndHalfTrigger = True # intermediate message done
 
